%global commit a8e82bcd63de14daddbc84c250a36c0ee8c850f6
%global shortcommit %(c=%{commit}; echo ${c:0:7})

Summary:        A Python interface to the HDF5 library
Name:           h5py
Version:        3.10.0
Release:    1%{?dist}
License:        BSD
URL:            http://www.h5py.org/
Source0:        https://files.pythonhosted.org/packages/source/h/h5py/h5py-%{version}.tar.gz
Patch0:         h5py-3.10.0-ppc-float128.patch
Patch1:         0001-Fix-compiling-fileobj-file-driver-with-Cython-3.0.patch
Patch2:         h5py-3.10.0-python-crash-file-test2.patch
BuildRequires:  gcc
BuildRequires:  hdf5-devel
BuildRequires:  liblzf-devel
BuildRequires:  python%{python3_pkgversion}-Cython >= 0.23
BuildRequires:  python%{python3_pkgversion}-devel >= 3.2
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-cached_property
BuildRequires:  python%{python3_pkgversion}-numpy >= 1.7
BuildRequires:  python%{python3_pkgversion}-pkgconfig
BuildRequires:  python%{python3_pkgversion}-pip
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-pytest-mpi
BuildRequires:  python%{python3_pkgversion}-six
BuildRequires:  python%{python3_pkgversion}-sphinx
%bcond_with openmpi 0
%if %{with openmpi}
BuildRequires:  hdf5-openmpi-devel
BuildRequires:  openmpi-devel
BuildRequires:  python%{python3_pkgversion}-mpi4py-openmpi
%endif
%bcond_with mpich 1
%if %{with mpich}
BuildRequires:  hdf5-mpich-devel
BuildRequires:  mpich-devel
BuildRequires:  python%{python3_pkgversion}-mpi4py-mpich
%endif

%global _description\
The h5py package provides both a high- and low-level interface to the\
HDF5 library from Python. The low-level interface is intended to be a\
complete wrapping of the HDF5 API, while the high-level component\
supports access to HDF5 files, data sets and groups using established\
Python and NumPy concepts.\
\
A strong emphasis on automatic conversion between Python (Numpy)\
data types and data structures and their HDF5 equivalents vastly\
simplifies the process of reading and writing data from Python.

%description %_description

%package     -n python%{python3_pkgversion}-h5py
Summary:        %{summary}
Requires:       hdf5 = %{_hdf5_version}
Requires:       python%{python3_pkgversion}-cached_property
Requires:       python%{python3_pkgversion}-numpy >= 1.7
Requires:       python%{python3_pkgversion}-six
%description -n python%{python3_pkgversion}-h5py %_description

%if %{with openmpi}
%package     -n python%{python3_pkgversion}-h5py-openmpi
Summary:        A Python interface to the HDF5 library using OpenMPI
Requires:       hdf5 = %{_hdf5_version}
Requires:       python%{python3_pkgversion}-cached_property
Requires:       python%{python3_pkgversion}-numpy >= 1.7
Requires:       python%{python3_pkgversion}-six
Requires:       python3-mpi4py-openmpi
Requires:       openmpi
%description -n python%{python3_pkgversion}-h5py-openmpi %_description
%endif

%if %{with mpich}
%package     -n python%{python3_pkgversion}-h5py-mpich
Summary:        A Python interface to the HDF5 library using MPICH
Requires:       hdf5 = %{_hdf5_version}
Requires:       python%{python3_pkgversion}-cached_property
Requires:       python%{python3_pkgversion}-numpy >= 1.7
Requires:       python%{python3_pkgversion}-six
Requires:       python3-mpi4py-openmpi
Requires:       python3-mpi4py-mpich
Requires:       mpich
%description -n python%{python3_pkgversion}-h5py-mpich %_description
%endif


%prep
%autosetup -N -c -n %{name}-%{version}
pushd %{name}-%{version}
%autopatch -p1
popd
mv %{name}-%{version} serial
cd serial
%{__python3} api_gen.py
cd -
%{?with_openmpi:cp -al serial openmpi}
%{?with_mpich:cp -al serial mpich}


%build
export H5PY_SETUP_REQUIRES=0
export H5PY_SYSTEM_LZF=1
export CFLAGS="%{optflags} -fopenmp"
cd serial
%py3_build
cd -

export CC=mpicc
export HDF5_MPI="ON"

%if %{with openmpi}
cd openmpi
%{_openmpi_load}
%py3_build
%{_openmpi_unload}
cd -
%endif

%if %{with mpich}
cd mpich
%{_mpich_load}
%py3_build
%{_mpich_unload}
cd -
%endif


%install
export H5PY_SETUP_REQUIRES=0
export H5PY_SYSTEM_LZF=1

%if %{with openmpi}
cd openmpi
%py3_install
rm -rf %{buildroot}%{python3_sitearch}/h5py/tests
mkdir -p %{buildroot}%{python3_sitearch}/openmpi
mv %{buildroot}%{python3_sitearch}/%{name}/ \
   %{buildroot}%{python3_sitearch}/%{name}*.egg-info \
   %{buildroot}%{python3_sitearch}/openmpi
cd -
%endif

%if %{with mpich}
cd mpich
%py3_install
rm -rf %{buildroot}%{python3_sitearch}/h5py/tests
mkdir -p %{buildroot}%{python3_sitearch}/mpich
mv %{buildroot}%{python3_sitearch}/%{name}/ \
   %{buildroot}%{python3_sitearch}/%{name}*.egg-info \
   %{buildroot}%{python3_sitearch}/mpich
cd -
%endif

cd serial
%py3_install
rm -rf %{buildroot}%{python3_sitearch}/h5py/tests
cd -


%check
exit 0
export H5PY_SETUP_REQUIRES=0
export H5PY_SYSTEM_LZF=1
%ifarch %ix86
fail=0
%else
fail=1
%endif

export PYTHONPATH=$(echo serial/build/lib*)
%{__python3} -m pytest --pyargs h5py -rxXs ${PYTHONPATH} || exit $fail

%if %{with openmpi}
export PYTHONPATH=$(echo openmpi/build/lib*)
%{_openmpi_load}
mpirun %{__python3} -m pytest --pyargs h5py -rxXs --with-mpi ${PYTHONPATH} || exit $fail
%{_openmpi_unload}
%endif

%if %{with mpich}
export PYTHONPATH=$(echo mpich/build/lib*)
%{_mpich_load}
mpirun %{__python3} -m pytest --pyargs h5py -rxXs --with-mpi ${PYTHONPATH} || exit $fail
%{_mpich_unload}
%endif


%files -n python%{python3_pkgversion}-h5py
%license serial/licenses/*.txt
%doc serial/README.rst serial/examples
%{python3_sitearch}/%{name}/
%{python3_sitearch}/%{name}-%{version}-*.egg-info

%if %{with openmpi}
%files -n python%{python3_pkgversion}-h5py-openmpi
%license openmpi/licenses/*.txt
%doc openmpi/README.rst
%{python3_sitearch}/openmpi/%{name}/
%{python3_sitearch}/openmpi/%{name}-%{version}-*.egg-info
%endif

%if %{with mpich}
%files -n python%{python3_pkgversion}-h5py-mpich
%license mpich/licenses/*.txt
%doc mpich/README.rst
%{python3_sitearch}/mpich/%{name}/
%{python3_sitearch}/mpich/%{name}-%{version}-*.egg-info
%endif


%changelog
* Mon Jul 01 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.10.0-1
- initial build
